#!/bin/sh

for DEP in hxselect lvs tempfile
do
	if [ -z "$(which $DEP)" ]
	then
		echo "kvmstats.sh: $DEP not found in \$PATH" 1>&2
		exit 1
	fi
done

TMPFILE=$(tempfile)

for VM in $(virsh list --all --name)
do
    VCPU=$(hxselect -c 'domain vcpu' </etc/libvirt/qemu/$VM.xml)
    RAM=$(hxselect -c 'domain memory' </etc/libvirt/qemu/$VM.xml)
    for DEV in $(hxselect -s'\n' 'domain devices disk[device=disk] source' </etc/libvirt/qemu/$VM.xml | cut -d\" -f2)
    do
        case $DEV in
        /dev/drbd/*) DISK=$(lvs --units b --nosuffix | awk "/$VM/ { ans += \$NF } END { print ans / 1024^3 }") ;;
        *.qcow2)     DISK=$(du -sBG $DEV |  awk '{ print substr($1, 0, length($1) - 1) }') ;;
        *)           DISK=0;;
        esac
    done
    echo $VM $VCPU $RAM $DISK
done >$TMPFILE

(
    echo vm vcpu ram disk
    cat $TMPFILE
    awk '{ vcpu += $2; ram += $3; disk += $4 } END { print "TOTAL", vcpu, ram, disk }' <$TMPFILE
) | column -t

rm $TMPFILE
